var NRS = (function(NRS, $) {

	var getForgingAccounts = function(callback) {
		var total = {};
		total.accounts_num = 0;
		total.total_balance = 0;
		total.total_hold = 0;
		total.total_par = 0;
		total.total_daily_par = 0;
		NRS.sendRequest("getForging+", {
			"adminPassword": NRS.getAdminPassword()
		}, function(response) {
			var accounts = response.generators;
			if (Array.isArray(accounts)) accounts = accounts.map(function(item) {
				return { "accountRS": item.accountRS };
			});
			for (var index in accounts) {
				NRS.sendRequest("getPara+", {
					"account": accounts[index].accountRS
				}, function(response) {
					if (response.balance) {
						accounts[index].balance = response.balance;
						total.total_balance += Number(response.balance);
						accounts[index].hold = response.hold;
						total.total_hold += Number(response.hold);
						accounts[index].amount = response.amount;
						accounts[index].last = response.last;
						accounts[index].height = response.height;
						accounts[index].holdStatus = NRS.lastBlockHeight >= 1200000 && NRS.lastBlockHeight - Number(response.height) <= 100000 && Number(response.balance) <= 11000000;
						accounts[index].par = Math.floor(new prizm.Para().calc(Number(response.balance), Number(response.amount), Number(response.last), Number(NRS.genesisAmount), accounts[index].holdStatus) * 100);
						total.total_par += accounts[index].par;
						accounts[index].daily_par = Math.floor(new prizm.Para().calc(Number(response.balance), Number(response.amount), Number(response.last) - 86400, Number(NRS.genesisAmount), accounts[index].holdStatus) * 100) - accounts[index].par;
						total.total_daily_par += accounts[index].daily_par;
					}
				}, false);
			}
			if (Array.isArray(accounts)) {
				total.accounts_num = accounts.length;
				accounts.sort((adr1, adr2) => Number(adr1.last) > Number(adr2.last) ? 1 : -1);
				if (accounts.length > NRS.itemsPerPage) NRS.hasMorePages = true;
				callback(accounts.slice(NRS.pageNumber * NRS.itemsPerPage - NRS.itemsPerPage, NRS.pageNumber * NRS.itemsPerPage), total);
			}

		});
	};

	NRS.setup.forging_accounts = function() {
		var options = {
			"id": 'sidebar_forging_accounts',
			"titleHTML": '<i class="fa fa-briefcase"></i> <span data-i18n="forging_accounts">Forging accounts</span>',
			"page": 'forging_accounts',
			"desiredPosition": 15
		};
		NRS.addSimpleSidebarMenuItem(options);
	};

	NRS.pages.forging_accounts = function() {
		getForgingAccounts(NRS.forging_accountsPageLoaded);
	};

	NRS.forging_accountsPageLoaded = function(accounts, total) {

		var rows = "";

		for (var index in accounts) {

			var account = accounts[index];
			var timeStart = NRS.constants.EPOCH_BEGINNING / 1000 + Number(account.last);
			var multi = new prizm.Para().multi(account.balance, account.amount);
			var paraTax = 0; if (Number(account.balance) > 0 && multi > 0) paraTax = Math.floor((1 - account.daily_par / Number(account.balance) / multi * 100) * 10000) / 100;
			
			rows += "<tr>" +
				"<td>" + NRS.getAccountLink(account, "account", undefined, undefined, true) + "</td>" +
				"<td>" + NRS.formatAmount((Number(account.balance) + Number(account.hold))/ 100) + "</td>" +
				"<td>" + NRS.formatAmount(account.hold / 100) + "</td>" +
				"<td>" + NRS.formatAmount(account.amount / 100) + "</td>" +
				"<td>" + (account.holdStatus ? Math.floor((Date.now() / 1000 - timeStart) / 86400) : 0) + "</td>" +
				"<td>" + NRS.formatAmount(account.par / 100) + "</td>" +
				"<td>" + NRS.formatAmount(account.daily_par / 100) + "</td>" +
				"<td>" + NRS.formatAmount(account.holdStatus ? NRS.lastBlockHeight - Number(account.height) : 0) + "</td>" +
				"<td>" + (paraTax > 0 ? paraTax : 0) + "%" + "</td>" +
			"</tr>";
		}

		NRS.dataLoaded(rows);

		if (Number(NRS.settings['theme'])) {
			$("#total_row").css('background-color', '#302a3e');
		} else {
			$("#total_row").css('background-color', '#f7f8ff');
		}

		$("#total_row").css('font-size', '38px').css('color', '#a8e');

		$("#accounts_num").html(total.accounts_num);
		$("#total_balance").html(NRS.formatStyledAmount((total.total_balance) / 100));
		$("#total_hold_amount").html(NRS.formatStyledAmount(total.total_hold / 100));
		$("#total_par").html(NRS.formatStyledAmount(total.total_par / 100));
		$("#total_daily_par").html(NRS.formatStyledAmount(total.total_daily_par / 100));		
	};

	return NRS;
}(NRS || {}, jQuery));